# ribbity

[![Build Status](https://github.com/ribbity-org/ribbity/workflows/Test/badge.svg)](https://github.com/ribbity-org/ribbity/actions/)
<a href="https://pypi.org/project/ribbity/"><img alt="PyPI" src="https://badge.fury.io/py/ribbity.svg"></a>
<a href="https://github.com/ribbity-org/ribbity/blob/latest/LICENSE"><img alt="License: 3-Clause BSD" src="https://img.shields.io/badge/License-BSD%203--Clause-blue.svg"></a>

Hop, frog, hop!

Turn a bunch of GitHub issues into a [mkdocs](https://www.mkdocs.org/)
site.

For example, turn
[the sourmash-bio/sourmash-examples issue tracker](https://github.com/sourmash-bio/sourmash-examples/issues/)
into [this site](https://sourmash-bio.github.io/sourmash-examples/).

## Project information

You can see the introductory blog post here: [Announcing ribbity - a hacky project to build Web sites from GitHub issue trackers](http://ivory.idyll.org/blog/2022-announcing-ribbity-github-issue-munging.html).

tl;dr Ribbity turns GitHub issue trackers into mkdocs sites that can be
hosted via GitHub pages.

If you want to see ribbity in action, we have a sandbox repo where you can play with it a bit!

* first, add an issue [over at ribbity-sandbox](https://github.com/ribbity-org/ribbity-sandbox/issues)!
* then, go to [the rendered sandbox site](https://ribbity-org.github.io/ribbity-sandbox/) and search for your issue text!

See ribbity documentation [here](https://ribbity-org.github.io/ribbity-docs/) and visit the source code [on GitHub](https://github.com/ribbity-org/ribbity).

---

Ribbity is released under the [BSD 3-Clause license](https://github.com/ribbity-org/ribbity/blob/main/LICENSE).

Please file issues [on GitHub](https://github.com/ribbity-org/ribbity/issues).
